==> entity_mesh-1.1.1.tar.gz: entity_mesh/tests/src/Kernel/EntityMeshEntityRenderTest.php <==
<?php

namespace Drupal\Tests\entity_mesh\Kernel;

use Drupal\node\Entity\Node;

/**
 * Tests the Entity Mesh link auditing without content_translation support.
 *
 * @group entity_mesh
 */
class EntityMeshEntityRenderTest extends EntityMeshTestBase {

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->container->get('kernel')->rebuildContainer();
    $this->container->get('router.builder')->rebuild();
    $this->createExampleNodes();

  }

  /**
   * Creates a node with given content.
   */
  protected function createExampleNodes() {

    // Create HTML content containing various link scenarios.
    $html_node_1 = '
      <p>External link https schema: <a href="https://example.com">Example</a></p>
      <p>External link http schema: <a href="http://example.com">Example</a></p>
      <p>Internal broken link: <a href="/non-existent">Broken</a></p>
      <p>Internal broken link node: <a href="/node/123">Broken Internal Node</a></p>
      <p>Iframe content: <iframe src="https://example.com/iframe"></iframe></p>
      <p>Mailto link: <a href="mailto:hola@metadrop.net">Mailto link</a></p>
      <p>Tel link: <a href="tel:+34654654654">Tel link</a></p>
    ';

    $node_1 = Node::create([
      'type' => 'page',
      'title' => 'Test Node 1',
      'nid' => 1,
      'body' => [
        'value' => $html_node_1,
        'format' => 'basic_html',
      ],
    ]);

    $node_1->save();

    $html_node_2 = '
      <p>Internal valid link: <a href="/node/1">Internal Node</a></p>
    ';

    $node_2 = Node::create([
      'type' => 'page',
      'title' => 'Test Node 2',
      'nid' => 2,
      'body' => [
        'value' => $html_node_2,
        'format' => 'basic_html',
      ],
    ]);
    $node_2->save();
  }

  /**
   * Provides test cases for different types of links.
   */
  public function linkCasesProvider() {
    $defaults = [
      'source_entity_id'                 => NULL,
      'target_href'                      => NULL,
      'expected_target_link_type'        => NULL,
      'excepted_target_subcategory'      => NULL,
      'expected_target_title'            => NULL,
      'expected_target_scheme'           => NULL,
      'expected_target_entity_type'      => NULL,
      'expected_target_entity_bundle'    => NULL,
      'expected_target_entity_id'        => NULL,
      'excepted_target_entity_langcode'  => NULL,
      'excepted_source_entity_type'      => NULL,
      'excepted_source_entity_bundle'    => NULL,
      'excepted_source_entity_langcode'  => NULL,
      'excepted_source_title'            => NULL,
    ];

    return [
      'External link HTTPS Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => 'https://example.com',
        'expected_target_link_type'       => 'external',
        'excepted_target_subcategory'     => 'link',
        'expected_target_title'           => 'https://example.com (external)',
        'expected_target_scheme'          => 'https',
        'excepted_source_entity_type'     => 'node',
        'excepted_source_entity_bundle'   => 'page',
        'excepted_source_title'           => 'Test Node 1 (node - 1)',
      ]),

      'External link HTTP Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => 'http://example.com',
        'expected_target_link_type'       => 'external',
        'excepted_target_subcategory'     => 'link',
        'expected_target_title'           => 'http://example.com (external)',
        'expected_target_scheme'          => 'http',
      ]),

      'Broken link alias Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => '/non-existent',
        'expected_target_link_type'       => 'internal',
        'excepted_target_subcategory'     => 'broken-link',
        'expected_target_title'           => '/non-existent ()',
      ]),

      'Broken link node Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => '/node/123',
        'expected_target_link_type'       => 'internal',
        'excepted_target_subcategory'     => 'broken-link',
        'expected_target_title'           => '/node/123 ()',
      ]),

      'Iframe link Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => 'https://example.com/iframe',
        'expected_target_link_type'       => 'external',
        'excepted_target_subcategory'     => 'iframe',
        'expected_target_title'           => 'https://example.com/iframe (external)',
        'expected_target_scheme'          => 'https',
      ]),

      'Mailto link Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => 'mailto:hola@metadrop.net',
        'expected_target_link_type'       => 'external',
        'excepted_target_subcategory'     => 'link',
        'expected_target_scheme'          => 'mailto',
      ]),

      'Tel link Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => 'tel:+34654654654',
        'expected_target_link_type'       => 'external',
        'excepted_target_subcategory'     => 'link',
        'expected_target_scheme'          => 'tel',
      ]),

      'Internal valid link Node 2' => array_merge($defaults, [
        'source_entity_id'                => 2,
        'target_href'                     => '/node/1',
        'expected_target_link_type'       => 'internal',
        'excepted_target_subcategory'     => 'link',
        'expected_target_title'           => 'Test Node 1 (node - 1)',
        'expected_target_entity_type'     => 'node',
        'expected_target_entity_bundle'   => 'page',
        'expected_target_entity_id'       => 1,
      ]),

    ];
  }

}

==> entity_mesh-1.1.5.tar.gz: entity_mesh/tests/src/Kernel/EntityMeshEntityRenderTest.php <==
<?php

namespace Drupal\Tests\entity_mesh\Kernel;

use Drupal\node\Entity\Node;

/**
 * Tests the Entity Mesh link auditing without content_translation support.
 *
 * @group entity_mesh
 */
class EntityMeshEntityRenderTest extends EntityMeshTestBase {

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->container->get('kernel')->rebuildContainer();
    $this->container->get('router.builder')->rebuild();
    $this->createExampleNodes();

  }

  /**
   * Creates a node with given content.
   */
  protected function createExampleNodes() {

    // Create HTML content containing various link scenarios.
    $html_node_1 = '
      <p>External link https schema: <a href="https://example.com">Example</a></p>
      <p>External link http schema: <a href="http://example.com">Example</a></p>
      <p>Internal broken link: <a href="/non-existent">Broken</a></p>
      <p>Internal broken link node: <a href="/node/123">Broken Internal Node</a></p>
      <p>Iframe content: <iframe src="https://example.com/iframe"></iframe></p>
      <p>Mailto link: <a href="mailto:hola@metadrop.net">Mailto link</a></p>
      <p>Tel link: <a href="tel:+34654654654">Tel link</a></p>
    ';

    $node_1 = Node::create([
      'type' => 'page',
      'title' => 'Test Node 1',
      'nid' => 1,
      'body' => [
        'value' => $html_node_1,
        'format' => 'basic_html',
      ],
    ]);

    $node_1->save();

    $html_node_2 = '
      <p>Internal valid link: <a href="/node/1">Internal Node</a></p>
    ';

    $node_2 = Node::create([
      'type' => 'page',
      'title' => 'Test Node 2',
      'nid' => 2,
      'body' => [
        'value' => $html_node_2,
        'format' => 'basic_html',
      ],
    ]);
    $node_2->save();
  }

  /**
   * Provides test cases for different types of links.
   */
  public static function linkCasesProvider() {
    $defaults = self::$providerDefaults;

    return [
      'External link HTTPS Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => 'https://example.com',
        'expected_target_link_type'       => 'external',
        'expected_target_subcategory'     => 'link',
        'expected_target_title'           => 'https://example.com (external)',
        'expected_target_scheme'          => 'https',
        'expected_source_entity_type'     => 'node',
        'expected_source_entity_bundle'   => 'page',
        'expected_source_title'           => 'Test Node 1 (node - 1)',
      ]),

      'External link HTTP Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => 'http://example.com',
        'expected_target_link_type'       => 'external',
        'expected_target_subcategory'     => 'link',
        'expected_target_title'           => 'http://example.com (external)',
        'expected_target_scheme'          => 'http',
      ]),

      'Broken link alias Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => '/non-existent',
        'expected_target_link_type'       => 'internal',
        'expected_target_subcategory'     => 'broken-link',
        'expected_target_title'           => '/non-existent ()',
      ]),

      'Broken link node Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => '/node/123',
        'expected_target_link_type'       => 'internal',
        'expected_target_subcategory'     => 'broken-link',
        'expected_target_title'           => '/node/123 ()',
      ]),

      'Iframe link Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => 'https://example.com/iframe',
        'expected_target_link_type'       => 'external',
        'expected_target_subcategory'     => 'iframe',
        'expected_target_title'           => 'https://example.com/iframe (external)',
        'expected_target_scheme'          => 'https',
      ]),

      'Mailto link Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => 'mailto:hola@metadrop.net',
        'expected_target_link_type'       => 'external',
        'expected_target_subcategory'     => 'link',
        'expected_target_scheme'          => 'mailto',
      ]),

      'Tel link Node 1' => array_merge($defaults, [
        'source_entity_id'                => 1,
        'target_href'                     => 'tel:+34654654654',
        'expected_target_link_type'       => 'external',
        'expected_target_subcategory'     => 'link',
        'expected_target_scheme'          => 'tel',
      ]),

      'Internal valid link Node 2' => array_merge($defaults, [
        'source_entity_id'                => 2,
        'target_href'                     => '/node/1',
        'expected_target_link_type'       => 'internal',
        'expected_target_subcategory'     => 'link',
        'expected_target_title'           => 'Test Node 1 (node - 1)',
        'expected_target_entity_type'     => 'node',
        'expected_target_entity_bundle'   => 'page',
        'expected_target_entity_id'       => 1,
      ]),

    ];
  }

}
